/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 *   Vladimir Vukicevic <vladimir@pobox.com>
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsIDOMHTMLElement.idl"

/**
 * The nsIDOMHTMLCanvasElement interface is the interface to a HTML
 * <canvas> element.
 *
 * For more information on this interface, please see
 * http://www.whatwg.org/specs/web-apps/current-work/#graphics
 *
 * @status UNDER_DEVELOPMENT
 */

interface nsIDOMFile;

[scriptable, uuid(28945fd6-c4a0-44e3-8629-98358eab5d7b)]
interface nsIDOMHTMLCanvasElement : nsIDOMHTMLElement
{
  attribute long width;
  attribute long height;
  attribute boolean mozOpaque;

  nsISupports getContext(in DOMString contextId);


  // Valid calls are:
  //  toDataURL();              -- defaults to image/png
  //  toDataURL(type);          -- uses given type
  //  toDataURL(type, params);  -- only available to trusted callers
  [optional_argc] DOMString toDataURL([optional] in DOMString type,
                                      [optional] in DOMString params);

  // This version lets you specify different image types and pass parameters
  // to the encoder. For example toDataURLAs("image/png", "transparency=none")
  // gives you a PNG with the alpha channel discarded. See the encoder for
  // the options string that it supports. Separate multiple options with
  // semicolons.
  [noscript] DOMString toDataURLAs(in DOMString mimeType, in DOMString encoderOptions);

 
  // Valid calls are
  // mozGetAsFile(name);              -- defaults to image/png
  // mozGetAsFile(name, type);        -- uses given type
  [optional_argc] nsIDOMFile mozGetAsFile(in DOMString name,
                                          [optional] in DOMString type);

  // A Mozilla-only extension to get a canvas context backed by double-buffered
  // shared memory. Only privileged callers can call this.
  nsISupports MozGetIPCContext(in DOMString contextId);
};

